@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from mopidy_somafm import Extension
 
 
@@ -8,8 +6,8 @@ def test_get_default_config():
 
     config = ext.get_default_config()
 
-    assert '[somafm]' in config
-    assert 'enabled = true' in config
+    assert "[somafm]" in config
+    assert "enabled = true" in config
 
 
 def test_get_config_schema():
@@ -17,5 +15,5 @@ def test_get_config_schema():
 
     schema = ext.get_config_schema()
 
-    assert 'quality' in schema
-    assert 'encoding' in schema
+    assert "quality" in schema
+    assert "encoding" in schema
