@@ -4,25 +4,24 @@ from mopidy_somafm.somafm import SomaFMClient
 
 
 class SomaFMClientTest(unittest.TestCase):
-
     def test_refresh(self):
         sfmc = SomaFMClient()
-        sfmc.refresh('mp3', 'fast')
+        sfmc.refresh("mp3", "fast")
 
         self.assertIsNotNone(sfmc.channels)
         self.assertNotEqual(len(sfmc.channels), 0)
 
     def test_refresh_firewall(self):
         sfmc = SomaFMClient()
-        sfmc.refresh('mp3', 'firewall')
+        sfmc.refresh("mp3", "firewall")
 
         self.assertIsNotNone(sfmc.channels)
         self.assertNotEqual(len(sfmc.channels), 0)
 
     def test_refresh_no_channels(self):
         sfmc = SomaFMClient()
-        sfmc.CHANNELS_URI = ''
-        sfmc.refresh('mp3', 'fast')
+        sfmc.CHANNELS_URI = ""
+        sfmc.refresh("mp3", "fast")
 
         self.assertDictEqual(sfmc.channels, {})
         self.assertEqual(len(sfmc.channels), 0)
